@@ -22,18 +22,20 @@ class Project:
         self,
         name: str,
         local_root: Optional[str] = None,
-        min_queue_size: Optional[int] = None,
-        batch_size: Optional[int] = None,
         distributed_api=DEFAULT_MULTI_API,
+        max_displays: int = 4,
+        max_cpu_use: float = float(cpu_count()),
         debug=False,
     ):
 
         self.depot = AswanDepot(name, local_root)
         self.object_store = ObjectStore(self.depot.object_store_path)
-        self.batch_size = batch_size or min(cpu_count() * 4, 60)
-        self.min_queue_size = min_queue_size or (self.batch_size // 2)
         self.distributed_api = distributed_api
         self.debug = debug
+        self.max_displays = max_displays
+        self.max_cpu_use = int(max_cpu_use * 1000)
+        self.batch_size = min(self.max_cpu_use * 4, 60)
+        self.min_queue_size = self.batch_size // 2
 
         self._handler_dic: Dict[str, urh.ANY_HANDLER_T] = {}
         self._scheduler: Optional[Scheduler] = None
@@ -141,12 +143,20 @@ class Project:
     @property
     def resource_limits(self):
         proxy_limits = {
-            k: p.max_at_once for k, p in self._proxy_dic.items() if p.max_at_once
+            handler.proxy.res_id: handler.proxy.max_at_once
+            for handler in self._handler_dic.values()
+            if handler.proxy.max_at_once
         }
-        # TODO stupid literals
+        handler_limits = {
+            h.name: h.max_in_parallel
+            for h in self._handler_dic.values()
+            if h.max_in_parallel is not None
+        }
+        # TODO add option to alternate cpu use
         return {
-            REnum.mCPU: int(cpu_count() * 1000),
-            REnum.DISPLAY: 4,
+            REnum.mCPU: self.max_cpu_use,
+            REnum.DISPLAY: self.max_displays,
+            **handler_limits,
             **proxy_limits,
         }
 
@@ -205,20 +215,12 @@ class Project:
 
     def _create_scheduler(self):
         self._scheduler = Scheduler(
-            actor_dict=get_actor_dict(self._proxy_dic.values()),
+            actor_dict=get_actor_dict(self._handler_dic.values()),
             resource_limits=self.resource_limits,
             distributed_system=self.distributed_api,  # TODO move test to sync?
             verbose=self.debug,
         )
 
-    @property
-    def _proxy_dic(self):
-        return {
-            handler.proxy.res_id: handler.proxy
-            for handler in self._handler_dic.values()
-            if handler.proxy
-        }
-
 
 class ParsedCollectionEvent:
     def __init__(self, cev: "CollEvent", project: Project):
